Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/FFmpeg/FFmpeg.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Bœsch <u@pkh.me>2016-06-21 22:55:20 +0300
committerClément Bœsch <u@pkh.me>2016-06-21 22:55:34 +0300
commit8ef57a0d6154119e1a616dd8c29e8c32e35808a0 (patch)
tree26c51bc5d99260b44ba3a2585091ca764559f939 /libavutil
parent373b82066cd4d0c7f42af9b03e8cdc1085e1a6e5 (diff)
parent41ed7ab45fc693f7d7fc35664c0233f4c32d69bb (diff)
Merge commit '41ed7ab45fc693f7d7fc35664c0233f4c32d69bb'
* commit '41ed7ab45fc693f7d7fc35664c0233f4c32d69bb': cosmetics: Fix spelling mistakes Merged-by: Clément Bœsch <u@pkh.me>
Diffstat (limited to 'libavutil')
-rw-r--r--libavutil/avassert.h2
-rw-r--r--libavutil/avr32/intreadwrite.h2
-rw-r--r--libavutil/avutil.h2
-rw-r--r--libavutil/frame.h2
-rw-r--r--libavutil/hwcontext.h4
-rw-r--r--libavutil/md5.c2
-rw-r--r--libavutil/opt.h2
-rw-r--r--libavutil/pixfmt.h22
-rw-r--r--libavutil/x86/cpu.c2
9 files changed, 20 insertions, 20 deletions
diff --git a/libavutil/avassert.h b/libavutil/avassert.h
index 41f5e0eea7..f473637649 100644
--- a/libavutil/avassert.h
+++ b/libavutil/avassert.h
@@ -45,7 +45,7 @@
/**
* assert() equivalent, that does not lie in speed critical code.
- * These asserts() thus can be enabled without fearing speedloss.
+ * These asserts() thus can be enabled without fearing speed loss.
*/
#if defined(ASSERT_LEVEL) && ASSERT_LEVEL > 0
#define av_assert1(cond) av_assert0(cond)
diff --git a/libavutil/avr32/intreadwrite.h b/libavutil/avr32/intreadwrite.h
index c6fd3aa470..95179f1d11 100644
--- a/libavutil/avr32/intreadwrite.h
+++ b/libavutil/avr32/intreadwrite.h
@@ -27,7 +27,7 @@
/*
* AVR32 does not support unaligned memory accesses, except for the AP
- * series which suppports unaligned 32-bit loads and stores. 16-bit
+ * series which supports unaligned 32-bit loads and stores. 16-bit
* and 64-bit accesses must be aligned to 16 and 32 bits, respectively.
* This means we cannot use the byte-swapping load/store instructions
* here.
diff --git a/libavutil/avutil.h b/libavutil/avutil.h
index 9bcf674126..c1f76c16ea 100644
--- a/libavutil/avutil.h
+++ b/libavutil/avutil.h
@@ -266,7 +266,7 @@ enum AVPictureType {
AV_PICTURE_TYPE_I, ///< Intra
AV_PICTURE_TYPE_P, ///< Predicted
AV_PICTURE_TYPE_B, ///< Bi-dir predicted
- AV_PICTURE_TYPE_S, ///< S(GMC)-VOP MPEG4
+ AV_PICTURE_TYPE_S, ///< S(GMC)-VOP MPEG-4
AV_PICTURE_TYPE_SI, ///< Switching Intra
AV_PICTURE_TYPE_SP, ///< Switching Predicted
AV_PICTURE_TYPE_BI, ///< BI type
diff --git a/libavutil/frame.h b/libavutil/frame.h
index b30aa4792e..44adec4602 100644
--- a/libavutil/frame.h
+++ b/libavutil/frame.h
@@ -328,7 +328,7 @@ typedef struct AVFrame {
int palette_has_changed;
/**
- * reordered opaque 64bit (generally an integer or a double precision float
+ * reordered opaque 64 bits (generally an integer or a double precision float
* PTS but can be anything).
* The user sets AVCodecContext.reordered_opaque to represent the input at
* that time,
diff --git a/libavutil/hwcontext.h b/libavutil/hwcontext.h
index 44be1977a8..7b93b20353 100644
--- a/libavutil/hwcontext.h
+++ b/libavutil/hwcontext.h
@@ -169,7 +169,7 @@ typedef struct AVHWFramesContext {
* A pool from which the frames are allocated by av_hwframe_get_buffer().
* This field may be set by the caller before calling av_hwframe_ctx_init().
* The buffers returned by calling av_buffer_pool_get() on this pool must
- * have the properties described in the documentation in the correponding hw
+ * have the properties described in the documentation in the corresponding hw
* type's header (hwcontext_*.h). The pool will be freed strictly before
* this struct's free() callback is invoked.
*
@@ -377,7 +377,7 @@ void *av_hwdevice_hwconfig_alloc(AVBufferRef *device_ctx);
/**
* Get the constraints on HW frames given a device and the HW-specific
* configuration to be used with that device. If no HW-specific
- * confgiuration is provided, returns the maximum possible capabilities
+ * configuration is provided, returns the maximum possible capabilities
* of the device.
*
* @param device_ctx a reference to the associated AVHWDeviceContext.
diff --git a/libavutil/md5.c b/libavutil/md5.c
index 057085b937..8c36aa80c4 100644
--- a/libavutil/md5.c
+++ b/libavutil/md5.c
@@ -8,7 +8,7 @@
*
* based on http://ubiqx.org/libcifs/source/Auth/MD5.c
* from Christopher R. Hertel (crh@ubiqx.mn.org)
- * Simplified, cleaned and IMO redundant comments removed by michael.
+ * Simplified, cleaned and IMO redundant comments removed by Michael.
*
* If you use gcc, then version 4.1 or later and -fomit-frame-pointer is
* strongly recommended.
diff --git a/libavutil/opt.h b/libavutil/opt.h
index 753434d628..9a76a47f75 100644
--- a/libavutil/opt.h
+++ b/libavutil/opt.h
@@ -281,7 +281,7 @@ typedef struct AVOption {
#define AV_OPT_FLAG_VIDEO_PARAM 16
#define AV_OPT_FLAG_SUBTITLE_PARAM 32
/**
- * The option is inteded for exporting values to the caller.
+ * The option is intended for exporting values to the caller.
*/
#define AV_OPT_FLAG_EXPORT 64
/**
diff --git a/libavutil/x86/cpu.c b/libavutil/x86/cpu.c
index bb63daac3d..b9f239be4f 100644
--- a/libavutil/x86/cpu.c
+++ b/libavutil/x86/cpu.c
@@ -182,7 +182,7 @@ int ff_get_cpu_flags_x86(void)
/* Similar to the above but for AVX functions on AMD processors.
This is necessary only for functions using YMM registers on Bulldozer
- and Jaguar based CPUs as they lack 256-bits execution units. SSE/AVX
+ and Jaguar based CPUs as they lack 256-bit execution units. SSE/AVX
functions using XMM registers are always faster on them.
AV_CPU_FLAG_AVX and AV_CPU_FLAG_AVXSLOW are both set so that AVX is
used unless explicitly disabled by checking AV_CPU_FLAG_AVXSLOW. */
diff --git a/libavutil/pixfmt.h b/libavutil/pixfmt.h
index 0fc78482a1..0ed01c4844 100644
--- a/libavutil/pixfmt.h
+++ b/libavutil/pixfmt.h
@@ -53,7 +53,7 @@
* to run on the IBM VGA graphics adapter use 6-bit palette components.
*
* @par
* For all the 8bit per pixel formats, an RGB32 palette is in data[1] like
* for pal8. This palette is filled in automatically by the function
* allocating the picture.
*/
@@ -70,7 +70,7 @@ enum AVPixelFormat {
AV_PIX_FMT_GRAY8, ///< Y , 8bpp
AV_PIX_FMT_MONOWHITE, ///< Y , 1bpp, 0 is white, 1 is black, in each byte pixels are ordered from the msb to the lsb
AV_PIX_FMT_MONOBLACK, ///< Y , 1bpp, 0 is black, 1 is white, in each byte pixels are ordered from the msb to the lsb
- AV_PIX_FMT_PAL8, ///< 8 bit with AV_PIX_FMT_RGB32 palette
+ AV_PIX_FMT_PAL8, ///< 8 bits with AV_PIX_FMT_RGB32 palette
AV_PIX_FMT_YUVJ420P, ///< planar YUV 4:2:0, 12bpp, full scale (JPEG), deprecated in favor of AV_PIX_FMT_YUV420P and setting color_range
AV_PIX_FMT_YUVJ422P, ///< planar YUV 4:2:2, 16bpp, full scale (JPEG), deprecated in favor of AV_PIX_FMT_YUV422P and setting color_range
AV_PIX_FMT_YUVJ444P, ///< planar YUV 4:4:4, 24bpp, full scale (JPEG), deprecated in favor of AV_PIX_FMT_YUV444P and setting color_range
@@ -143,7 +143,7 @@ enum AVPixelFormat {
AV_PIX_FMT_YUV444P16LE, ///< planar YUV 4:4:4, 48bpp, (1 Cr & Cb sample per 1x1 Y samples), little-endian
AV_PIX_FMT_YUV444P16BE, ///< planar YUV 4:4:4, 48bpp, (1 Cr & Cb sample per 1x1 Y samples), big-endian
#if FF_API_VDPAU
- AV_PIX_FMT_VDPAU_MPEG4, ///< MPEG4 HW decoding with VDPAU, data[0] contains a vdpau_render_state struct which contains the bitstream of the slices as well as various fields extracted from headers
+ AV_PIX_FMT_VDPAU_MPEG4, ///< MPEG-4 HW decoding with VDPAU, data[0] contains a vdpau_render_state struct which contains the bitstream of the slices as well as various fields extracted from headers
#endif
AV_PIX_FMT_DXVA2_VLD, ///< HW decoding through DXVA2, Picture.data[3] contains a LPDIRECT3DSURFACE9 pointer
@@ -151,7 +151,7 @@ enum AVPixelFormat {
AV_PIX_FMT_RGB444BE, ///< packed RGB 4:4:4, 16bpp, (msb)4X 4R 4G 4B(lsb), big-endian, X=unused/undefined
AV_PIX_FMT_BGR444LE, ///< packed BGR 4:4:4, 16bpp, (msb)4X 4B 4G 4R(lsb), little-endian, X=unused/undefined
AV_PIX_FMT_BGR444BE, ///< packed BGR 4:4:4, 16bpp, (msb)4X 4B 4G 4R(lsb), big-endian, X=unused/undefined
- AV_PIX_FMT_YA8, ///< 8bit gray, 8bit alpha
+ AV_PIX_FMT_YA8, ///< 8 bits gray, 8 bits alpha
AV_PIX_FMT_Y400A = AV_PIX_FMT_YA8, ///< alias for AV_PIX_FMT_YA8
AV_PIX_FMT_GRAY8A= AV_PIX_FMT_YA8, ///< alias for AV_PIX_FMT_YA8
@@ -222,8 +222,8 @@ enum AVPixelFormat {
AV_PIX_FMT_VDA, ///< HW acceleration through VDA, data[3] contains a CVPixelBufferRef
- AV_PIX_FMT_YA16BE, ///< 16bit gray, 16bit alpha (big-endian)
- AV_PIX_FMT_YA16LE, ///< 16bit gray, 16bit alpha (little-endian)
+ AV_PIX_FMT_YA16BE, ///< 16 bits gray, 16 bits alpha (big-endian)
+ AV_PIX_FMT_YA16LE, ///< 16 bits gray, 16 bits alpha (little-endian)
AV_PIX_FMT_GBRAP, ///< planar GBRA 4:4:4:4 32bpp
AV_PIX_FMT_GBRAP16BE, ///< planar GBRA 4:4:4:4 64bpp, big-endian
@@ -420,9 +420,9 @@ enum AVColorTransferCharacteristic {
AVCOL_TRC_IEC61966_2_4 = 11, ///< IEC 61966-2-4
AVCOL_TRC_BT1361_ECG = 12, ///< ITU-R BT1361 Extended Colour Gamut
AVCOL_TRC_IEC61966_2_1 = 13, ///< IEC 61966-2-1 (sRGB or sYCC)
- AVCOL_TRC_BT2020_10 = 14, ///< ITU-R BT2020 for 10 bit system
- AVCOL_TRC_BT2020_12 = 15, ///< ITU-R BT2020 for 12 bit system
- AVCOL_TRC_SMPTEST2084 = 16, ///< SMPTE ST 2084 for 10, 12, 14 and 16 bit systems
+ AVCOL_TRC_BT2020_10 = 14, ///< ITU-R BT2020 for 10-bit system
+ AVCOL_TRC_BT2020_12 = 15, ///< ITU-R BT2020 for 12-bit system
+ AVCOL_TRC_SMPTEST2084 = 16, ///< SMPTE ST 2084 for 10-, 12-, 14- and 16-bit systems
AVCOL_TRC_SMPTEST428_1 = 17, ///< SMPTE ST 428-1
AVCOL_TRC_ARIB_STD_B67 = 18, ///< ARIB STD-B67, known as "Hybrid log-gamma"
AVCOL_TRC_NB, ///< Not part of ABI
@@ -475,8 +475,8 @@ enum AVColorRange {
*/
enum AVChromaLocation {
AVCHROMA_LOC_UNSPECIFIED = 0,
- AVCHROMA_LOC_LEFT = 1, ///< mpeg2/4 4:2:0, h264 default for 4:2:0
- AVCHROMA_LOC_CENTER = 2, ///< mpeg1 4:2:0, jpeg 4:2:0, h263 4:2:0
+ AVCHROMA_LOC_LEFT = 1, ///< MPEG-2/4 4:2:0, H.264 default for 4:2:0
+ AVCHROMA_LOC_CENTER = 2, ///< MPEG-1 4:2:0, JPEG 4:2:0, H.263 4:2:0
AVCHROMA_LOC_TOPLEFT = 3, ///< ITU-R 601, SMPTE 274M 296M S314M(DV 4:1:1), mpeg2 4:2:2
AVCHROMA_LOC_TOP = 4,
AVCHROMA_LOC_BOTTOMLEFT = 5,
@@ -53,7 +53,7 @@
*
* @par
- * For all the 8bit per pixel formats, an RGB32 palette is in data[1] like
+ * For all the 8 bits per pixel formats, an RGB32 palette is in data[1] like
* for pal8. This palette is filled in automatically by the function
* allocating the picture.